==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/hole/dialogs_cs.lua <==
dialogId("m-strasidelna", "font_small", "It is a haunted room.")
dialogStr("To je ale strašidelná místnost.")

dialogId("v-bojim", "font_big",
"I fear it will be dificult to move things over this hole.")
dialogStr(
"Taky se bojím..., že přes tu propast budem tězko dostávat předměty.")

dialogId("s-prejete", "font_green", "Here you are, as you wish.")
dialogStr("Prosím, jak si přejete.")

dialogId("l-halo0", "font_lightgrey", "Is anybody there?")
dialogStr("Haló, je tam někdo?")

dialogId("l-halo1", "font_lightgrey", "Who are there?")
dialogStr("Kdo tam je?")

dialogId("l-halo2", "font_lightgrey", "I think, the receiver does not work.")
dialogStr("Dost pochybuji o funkčnosti toho sluchátka.")

dialogId("l-dejte0", "font_lightgrey",
         "Put it back immediately, the indian headdress is mine.")
dialogStr("Dejte to sem, ta indiánská čelenka je moje!")

dialogId("l-dejte1", "font_lightgrey", "Put it back immediately, it is mine!")
dialogStr("Dejte to sem, to je moje!")

dialogId("l-dejte2", "font_lightgrey",
         "O O O O, I am indian. Put it back immediately!")
dialogStr("O O O O, jsem indián, dejte to sem!")

dialogId("l-dejte3", "font_lightgrey", "O O O O, put it back immediately!")
dialogStr("O O O O, dejte to sem")

dialogId("l-vinnetou", "font_lightgrey",
         "Where are you pushing me? I am famous Vinnetou!")
dialogStr("Kam mě to strkáte? Já jsem slavný Vinnetou!")

dialogId("m-nedame0", "font_small",
         "Sorry, we need it necessarily.")
dialogStr("Promiň, ale my ji teď nutně potřebujeme.")

dialogId("v-nedame0", "font_big",
"How can it be yours, if you are not indian?")
dialogStr("Jak může být tvoje, když nejsi indián?")

dialogId("m-nedame1", "font_small",
         "You can't be indian because you are not red?")
dialogStr("Jak můžeš být indián, když nejsi červený?")

dialogId("v-nedame1", "font_big", "I can't demur anything.")
dialogStr("Na to už se nedá nic namítat.")

dialogId("v-neber", "font_big",
"Player, if you are an indian, don't perceive as an discrimination please.")
dialogStr(
"Pokud, hráči, náhodou jsi indián, tak to prosím neber jako diskriminaci.")

dialogId("m-sluchatko", "font_small", "It may be magic receiver.")
dialogStr("To bude možná sluchátko Macha a Šebestové.")

dialogId("v-zkus", "font_big", "Try it.")
dialogStr("Tak to zkus.")

dialogId("m-zmizet", "font_small",
         "Hello, I wish to disappear the steel near exit?")
dialogStr("Haló, mohla by ta ocel u východu na chvíli zmizet?")

dialogId("v-vratte", "font_big",
         "Put it back, it should be solved by player, not by ourself.")
dialogStr("Vraťte ji zpátky, aby to musel vyřešit hráč a ne my.")

==> fillets-ng-data_0.9.2.orig.tar.gz: fillets-ng-data-0.9.2/script/hole/dialogs_cs.lua <==
dialogId("m-strasidelna", "font_small", "It is a haunted room.")
dialogStr("To je ale strašidelná místnost.")

dialogId("v-bojim", "font_big",
"I fear it will be dificult to move things over this hole.")
dialogStr(
"Taky se bojím..., že přes tu propast budem tězko dostávat předměty.")

dialogId("s-prejete", "font_green", "Here you are, as you wish.")
dialogStr("Prosím, jak si přejete.")

dialogId("l-halo0", "font_lightgrey", "Is anybody there?")
dialogStr("Haló, je tam někdo?")

dialogId("l-halo1", "font_lightgrey", "Who are there?")
dialogStr("Kdo tam je?")

dialogId("l-halo2", "font_lightgrey", "I think, the receiver does not work.")
dialogStr("Dost pochybuji o funkčnosti toho sluchátka.")

dialogId("l-dejte0", "font_lightgrey",
         "Put it back immediately, the indian headdress is mine.")
dialogStr("Dejte to sem, ta indiánská čelenka je moje!")

dialogId("l-dejte1", "font_lightgrey", "Put it back immediately, it is mine!")
dialogStr("Dejte to sem, to je moje!")

dialogId("l-dejte2", "font_lightgrey",
         "O O O O, I am indian. Put it back immediately!")
dialogStr("O O O O, jsem indián, dejte to sem!")

dialogId("l-dejte3", "font_lightgrey", "O O O O, put it back immediately!")
dialogStr("O O O O, dejte to sem")

dialogId("l-vinnetou", "font_lightgrey",
         "Where are you pushing me? I am famous Vinnetou!")
dialogStr("Kam mě to strkáte? Já jsem slavný Vinnetou!")

dialogId("m-nedame0", "font_small",
         "Sorry, we need it necessarily.")
dialogStr("Promiň, ale my ji teď nutně potřebujeme.")

dialogId("v-nedame0", "font_big",
"How can it be yours, if you are not indian?")
dialogStr("Jak může být tvoje, když nejsi indián?")

dialogId("m-nedame1", "font_small", "You can’t be indian because you are not red?")
dialogStr("Jak můžeš být indián, když nejsi červený?")

dialogId("v-nedame1", "font_big", "I can’t demur anything.")
dialogStr("Na to už se nedá nic namítat.")

dialogId("v-neber", "font_big", "Player, if you are an indian, don’t perceive as an discrimination please.")
dialogStr(
"Pokud, hráči, náhodou jsi indián, tak to prosím neber jako diskriminaci.")

dialogId("m-sluchatko", "font_small", "It may be magic receiver.")
dialogStr("To bude možná sluchátko Macha a Šebestové.")

dialogId("v-zkus", "font_big", "Try it.")
dialogStr("Tak to zkus.")

dialogId("m-zmizet", "font_small",
         "Hello, I wish to disappear the steel near exit?")
dialogStr("Haló, mohla by ta ocel u východu na chvíli zmizet?")

dialogId("v-vratte", "font_big",
         "Put it back, it should be solved by player, not by ourself.")
dialogStr("Vraťte ji zpátky, aby to musel vyřešit hráč a ne my.")
